Contributing
============

First of all, thank you for your interest in contributing to OverPy!


Filing bug reports
------------------

Bug reports are very welcome.
Please fill them on the `GitHub issue tracker`_.
Good bug reports come with extensive descriptions of the error and how to reproduce it.


Patches
-------

All patches to OverPy should be submitted in the form of pull requests to the main OverPy repository, `DinoTools/python-overpy`_.
These pull requests should satisfy the following properties:

Code
^^^^

- The pull request should focus on one particular improvement to OverPy.
- Create different pull requests for unrelated features or bugfixes.
- Python code should follow `PEP 8`_, especially in the "do what code around you does" sense.

Documentation
^^^^^^^^^^^^^

When introducing new functionality, please remember to write documentation.

Tests
^^^^^

It is recommended to add tests for new code you add.

Review
------

Finally, pull requests must be reviewed before merging.
Everyone can perform reviews; this is a very valuable way to contribute, and is highly encouraged.


.. _GitHub issue tracker: https://github.com/DinoTools/python-overpy/issues
.. _DinoTools/python-overpy: https://github.com/DinoTools/python-overpy
.. _PEP 8: https://www.python.org/dev/peps/pep-0008/
